pub struct PackFaults { /* private fields */ }Expand description
Pack and BMS fault flags
Implementations
Sourceimpl PackFaults
impl PackFaults
Sourcepub const OVER_VOLTAGE: Self
pub const OVER_VOLTAGE: Self
Cell is over its configured over-voltage threshold
Sourcepub const UNDER_VOLTAGE: Self
pub const UNDER_VOLTAGE: Self
Cell is over its configured over-voltage threshold
Sourcepub const NTC_OVER_TEMP: Self
pub const NTC_OVER_TEMP: Self
Pack is over it’s configured over-temperature threshold
Sourcepub const NTC_UNDER_TEMP: Self
pub const NTC_UNDER_TEMP: Self
Pack is under it’s configured under-temperature threshold
Sourcepub const NTC_SEVERE_OVER_TEMP: Self
pub const NTC_SEVERE_OVER_TEMP: Self
Pack is over it’s configured severe over-temperature threshold
Sourcepub const DIE_OVER_TEMP: Self
pub const DIE_OVER_TEMP: Self
BMS Die over-temperature
Sourcepub const CELL_VOLTAGE_SUM_VB_MISMATCH: Self
pub const CELL_VOLTAGE_SUM_VB_MISMATCH: Self
Mismatch between cell measurements and pack voltage
Sourcepub const COULOMB_COUNTER_SATURATED: Self
pub const COULOMB_COUNTER_SATURATED: Self
Coulomb counter saturation
Sourcepub const OVER_CURRENT_CHARGE: Self
pub const OVER_CURRENT_CHARGE: Self
Over current during charge
Sourcepub const PERSISTENT_OVER_CURRENT_IN_CHARGE: Self
pub const PERSISTENT_OVER_CURRENT_IN_CHARGE: Self
Persistent over-current during charge
Sourcepub const OVER_CURRENT_DISCHARGE: Self
pub const OVER_CURRENT_DISCHARGE: Self
Over current during discharge
Sourcepub const PERSISTENT_OVER_CURRENT_IN_DISCHARGE: Self
pub const PERSISTENT_OVER_CURRENT_IN_DISCHARGE: Self
Persistent over-current during discharge
Sourcepub const SHORT_CIRCUIT_DISCHARGE: Self
pub const SHORT_CIRCUIT_DISCHARGE: Self
Short circuit during discharge
Sourcepub const PERSISTENT_SHORT_CIRCUIT_DISCHARGE: Self
pub const PERSISTENT_SHORT_CIRCUIT_DISCHARGE: Self
Persistent short circuit during discharge
Sourcepub const FUSE_EXTERNAL: Self
pub const FUSE_EXTERNAL: Self
Fuse External fault
Sourcepub const FAULTN_EXTERNAL: Self
pub const FAULTN_EXTERNAL: Self
FaultN External fault
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u16) -> Self
pub const unsafe fn from_bits_unchecked(bits: u16) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.