L9961 Industrial BMS Driver
This driver aims to provide a robust API for building battery packs utilizing the STMicro L9961 BMS Chip.
The crate is built on top of the embedded-hal and embedded-hal-async traits.
The driver requires an async runtime to function, and has been tested with both Embassy as well as RTIC 2.x.
Re-exports
Modules
- commands
- Commands
- config
- Configuration
- conversions
- Conversion functions for the L9961
- faults
- The fault module defines the faults returned by the L9961 driver when making measurements It implements the logic to translate the fault registers into the measurement struct, and to clear the fault registers while doing so.
- measurement
- The measurement module contains the entry point for periodically measuring the cell voltages and temperatures, as well as initiating the fault handling process should faults occur during measurement.
- registers
- Registers
Structs
- L9961
- L9961 Industrial BMS Driver